@@ -23,7 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <KXmlGuiWindow>
 
-#include "ui_settingsBase.h"
+#include "ui_settings.h"
 #include "%{APPNAME}Settings.h"
 
 class %{APPNAME}View;
@@ -64,7 +64,7 @@ private Q_SLOTS:
 private:
     // this is the name of the root widget inside our Ui file
     // you can rename it in designer and then change it here
-    Ui::settingsBase settingsBase;
+    Ui::Settings m_settings;
     QAction *m_switchAction;
     %{APPNAME}View *m_%{APPNAMELC}View;
 };
